@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::listdeps;
 {
-  $Dist::Zilla::App::Command::listdeps::VERSION = '4.300029';
+  $Dist::Zilla::App::Command::listdeps::VERSION = '4.300031';
 }
 use Dist::Zilla::App -command;
 # ABSTRACT: print your distribution's prerequisites
@@ -15,11 +15,12 @@ sub abstract { "print your distribution's prerequisites" }
 sub opt_spec {
   [ 'author', 'include author dependencies' ],
   [ 'missing', 'list only the missing dependencies' ],
-  [ 'versions', 'include required version numbers in listing' ]
+  [ 'versions', 'include required version numbers in listing' ],
+  [ 'json', 'list dependencies by phase, in JSON format' ],
 }
 
-sub extract_dependencies {
-  my ($self, $zilla, $phases, $missing) = @_;
+sub prereqs {
+  my ($self, $zilla) = @_;
 
   $_->before_build for @{ $zilla->plugins_with(-BeforeBuild) };
   $_->gather_files for @{ $zilla->plugins_with(-FileGatherer) };
@@ -27,9 +28,16 @@ sub extract_dependencies {
   $_->munge_files  for @{ $zilla->plugins_with(-FileMunger) };
   $_->register_prereqs for @{ $zilla->plugins_with(-PrereqSource) };
 
+  my $prereqs = $zilla->prereqs;
+}
+
+sub extract_dependencies {
+  my ($self, $zilla, $phases, $missing) = @_;
+
+  my $prereqs = $self->prereqs($zilla);
+
   require CPAN::Meta::Requirements;
   my $req = CPAN::Meta::Requirements->new;
-  my $prereqs = $zilla->prereqs;
 
   for my $phase (@$phases) {
     $req->add_requirements( $prereqs->requirements_for($phase, 'requires') );
@@ -66,10 +74,19 @@ sub execute {
   my @phases = qw(build test configure runtime);
   push @phases, 'develop' if $opt->author;
 
+  if($opt->json) {
+    my $prereqs = $self->prereqs($self->zilla);
+    my $output = $prereqs->as_string_hash;
+
+    require JSON; JSON->VERSION(2);
+    print JSON->new->ascii(1)->canonical(1)->pretty->encode($output), "\n";
+    return 1;
+  }
+
   my %modules = $self->extract_dependencies($self->zilla, \@phases, $opt->missing);
 
   if($opt->versions) {
-    for(sort { lc $a cmp $b } keys %modules) {
+    for(sort { lc $a cmp lc $b } keys %modules) {
       print "$_ = ".$modules{$_}."\n";
     }
   } else {
@@ -89,7 +106,7 @@ Dist::Zilla::App::Command::listdeps - print your distribution's prerequisites
 
 =head1 VERSION
 
-version 4.300029
+version 4.300031
 
 =head1 SYNOPSIS
 
@@ -116,9 +133,14 @@ List only dependencies which are unsatisfied.
 
 Also display the required versions of listed modules.
 
+=head2 --json
+
+Lists all prerequisites in JSON format, as they would appear in META.json
+(broken out into phases and types)
+
 =head1 ACKNOWLEDGEMENTS
 
-This code is more or less a direct copy of Marcel Gruenauer (hanekomu)
+This code was originally more or less a direct copy of Marcel Gruenauer (hanekomu)
 Dist::Zilla::App::Command::prereqs, updated to work with the Dist::Zilla v2
 API.
 
