@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GatherDir;
 {
-  $Dist::Zilla::Plugin::GatherDir::VERSION = '4.300029';
+  $Dist::Zilla::Plugin::GatherDir::VERSION = '4.300031';
 }
 # ABSTRACT: gather all the files in a directory
 use Moose;
@@ -71,9 +71,8 @@ sub gather_files {
   my $exclude_regex = qr/\000/;
   $exclude_regex = qr/$exclude_regex|$_/
     for ($self->exclude_match->flatten);
-  # \b\Q$_\E\b should also handle the `eq` check
-  $exclude_regex = qr/$exclude_regex|\b\Q$_\E\b/
-    for ($self->exclude_filename->flatten);
+
+  my %is_excluded = map {; $_ => 1 } $self->exclude_filename->flatten;
 
   my $root = "" . $self->root;
   $root =~ s{^~([\\/])}{File::HomeDir->my_home . $1}e;
@@ -90,6 +89,7 @@ sub gather_files {
     }
 
     next if $file =~ $exclude_regex;
+    next if $is_excluded{ $file };
 
     # _file_from_filename is overloaded in GatherDir::Template
     my $fileobj = $self->_file_from_filename($filename);
@@ -125,7 +125,7 @@ Dist::Zilla::Plugin::GatherDir - gather all the files in a directory
 
 =head1 VERSION
 
-version 4.300029
+version 4.300031
 
 =head1 DESCRIPTION
 
